@@ -17,14 +17,16 @@ namespace gridtools {
     namespace binop {
         struct sum {
             template <class Lhs, class Rhs>
-            GT_FUNCTION GT_CONSTEXPR auto operator()(Lhs &&lhs, Rhs &&rhs) const
-                GT_AUTO_RETURN(wstd::forward<Lhs>(lhs) + wstd::forward<Rhs>(rhs));
+            GT_FUNCTION GT_CONSTEXPR auto operator()(Lhs &&lhs, Rhs &&rhs) const {
+                return wstd::forward<Lhs>(lhs) + wstd::forward<Rhs>(rhs);
+            }
         };
 
         struct prod {
             template <class Lhs, class Rhs>
-            GT_FUNCTION GT_CONSTEXPR auto operator()(Lhs &&lhs, Rhs &&rhs) const
-                GT_AUTO_RETURN(wstd::forward<Lhs>(lhs) * wstd::forward<Rhs>(rhs));
+            GT_FUNCTION GT_CONSTEXPR auto operator()(Lhs &&lhs, Rhs &&rhs) const {
+                return wstd::forward<Lhs>(lhs) * wstd::forward<Rhs>(rhs);
+            }
         };
     } // namespace binop
 } // namespace gridtools
