@@ -26,14 +26,14 @@ namespace gridtools {
 
     /* check if all given types are integral types */
     template <typename... IntTypes>
-    GT_META_DEFINE_ALIAS(is_all_integral, conjunction, std::is_integral<IntTypes>...);
+    using is_all_integral = conjunction<std::is_integral<IntTypes>...>;
 
     template <typename T>
-    GT_META_DEFINE_ALIAS(is_integral_or_enum, bool_constant, std::is_integral<T>::value || std::is_enum<T>::value);
+    using is_integral_or_enum = bool_constant<std::is_integral<T>::value || std::is_enum<T>::value>;
 
     /* check if all given types are integral types or enums */
     template <typename... IntTypes>
-    GT_META_DEFINE_ALIAS(is_all_integral_or_enum, conjunction, is_integral_or_enum<IntTypes>...);
+    using is_all_integral_or_enum = conjunction<is_integral_or_enum<IntTypes>...>;
     /** @} */
     /** @} */
     /** @} */
