@@ -10,6 +10,7 @@
 #pragma once
 
 #include <type_traits>
+#include <utility>
 
 #include "defs.hpp"
 
@@ -28,9 +29,7 @@ namespace gridtools {
      *  @tparam Bitmask bitmask defining the masked and unmasked dimensions
      */
     template <bool... Bitmask>
-    struct selector {
-        static constexpr uint_t size = sizeof...(Bitmask);
-    };
+    using selector = std::integer_sequence<bool, Bitmask...>;
 
     template <typename T>
     struct is_selector : std::false_type {};
