@@ -10,12 +10,10 @@
 #pragma once
 
 #include "../../common/array.hpp"
-#include "../../common/generic_metafunctions/pack_get_elem.hpp"
 #include "../../common/gt_assert.hpp"
 #include "../../common/make_array.hpp"
 #include "../low_level/Halo_Exchange_3D.hpp"
 #include "../low_level/proc_grids_3D.hpp"
-#include <boost/type_traits/remove_pointer.hpp>
 #include <vector>
 
 #include "../../common/boollist.hpp"
@@ -27,11 +25,6 @@
 #include "empty_field_base.hpp"
 #include "gcl_parameters.hpp"
 #include "helpers_impl.hpp"
-#include <boost/preprocessor/arithmetic/inc.hpp>
-#include <boost/preprocessor/punctuation/comma_if.hpp>
-#include <boost/preprocessor/repetition/enum_binary_params.hpp>
-#include <boost/preprocessor/repetition/enum_params.hpp>
-#include <boost/preprocessor/repetition/repeat.hpp>
 
 namespace gridtools {
 
@@ -567,9 +560,9 @@ namespace gridtools {
                     for (int jj = -1; jj <= 1; ++jj) {
                         for (int kk = -1; kk <= 1; ++kk) {
                             typedef proc_layout map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                             if ((ii != 0 || jj != 0 || kk != 0) &&
                                 (hm.pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1)) {
                                 DataType *it = &(hm.send_buffer[translate()(ii, jj, kk)][0]);
@@ -604,9 +597,9 @@ namespace gridtools {
                     for (int jj = -1; jj <= 1; ++jj) {
                         for (int kk = -1; kk <= 1; ++kk) {
                             typedef proc_layout map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                             if ((ii != 0 || jj != 0 || kk != 0) &&
                                 (hm.pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1)) {
                                 DataType *it = &(hm.recv_buffer[translate()(ii, jj, kk)][0]);
@@ -630,9 +623,9 @@ namespace gridtools {
                     for (int jj = -1; jj <= 1; ++jj) {
                         for (int kk = -1; kk <= 1; ++kk) {
                             typedef proc_layout map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                             if ((ii != 0 || jj != 0 || kk != 0) &&
                                 (hm.pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1)) {
                                 DataType *it = &(hm.send_buffer[translate()(ii, jj, kk)][0]);
@@ -669,9 +662,9 @@ namespace gridtools {
                     for (int jj = -1; jj <= 1; ++jj) {
                         for (int kk = -1; kk <= 1; ++kk) {
                             typedef proc_layout map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                             if ((ii != 0 || jj != 0 || kk != 0) &&
                                 (hm.pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1)) {
                                 DataType *it = &(hm.recv_buffer[translate()(ii, jj, kk)][0]);
