@@ -8,7 +8,7 @@
  * SPDX-License-Identifier: BSD-3-Clause
  */
 
-#include "../../meta/utility.hpp"
+#include <utility>
 
 #ifdef __CUDACC__
 #include "m_packXL.hpp"
@@ -219,9 +219,9 @@ namespace gridtools {
                 int ii = 1;
                 int jj = 0;
                 int kk = 0;
-                const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                 if ((base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) == -1)) {
                     dangeroushalo[0].reset_minus();
                     dangeroushalo_r[0].reset_plus();
@@ -232,9 +232,9 @@ namespace gridtools {
                 int ii = -1;
                 int jj = 0;
                 int kk = 0;
-                const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                 if ((base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) == -1)) {
                     dangeroushalo[0].reset_plus();
                     dangeroushalo_r[0].reset_minus();
@@ -245,9 +245,9 @@ namespace gridtools {
                 int ii = 0;
                 int jj = 1;
                 int kk = 0;
-                const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                 if ((base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) == -1)) {
                     dangeroushalo[1].reset_minus();
                     dangeroushalo_r[1].reset_plus();
@@ -258,9 +258,9 @@ namespace gridtools {
                 int ii = 0;
                 int jj = -1;
                 int kk = 0;
-                const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                 if ((base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) == -1)) {
                     dangeroushalo[1].reset_plus();
                     dangeroushalo_r[1].reset_minus();
@@ -271,9 +271,9 @@ namespace gridtools {
                 int ii = 0;
                 int jj = 0;
                 int kk = 1;
-                const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                 if ((base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) == -1)) {
                     dangeroushalo[2].reset_minus();
                     dangeroushalo_r[2].reset_plus();
@@ -284,9 +284,9 @@ namespace gridtools {
                 int ii = 0;
                 int jj = 0;
                 int kk = -1;
-                const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
                 if ((base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) == -1)) {
                     dangeroushalo[2].reset_plus();
                     dangeroushalo_r[2].reset_minus();
@@ -339,9 +339,9 @@ namespace gridtools {
                     for (int kk = -1; kk <= 1; ++kk)
                         if (ii != 0 || jj != 0 || kk != 0) {
                             typedef typename translate_P::map_type map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
 
                             if (base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1) {
                                 send_size[translate()(ii, jj, kk)] = halo.send_buffer_size(make_array(ii, jj, kk));
@@ -426,7 +426,7 @@ namespace gridtools {
         template <typename... Pointers>
         void pack(const Pointers *... fields) {
             typedef translate_t<3, default_layout_map<3>::type> translate;
-            auto ints = meta::make_integer_sequence<unsigned int, sizeof...(Pointers)>{};
+            auto ints = std::make_integer_sequence<unsigned int, sizeof...(Pointers)>{};
             if (send_size[translate()(0, 0, -1)]) {
                 m_packZL_variadic(d_send_buffer, d_send_size, dangeroushalo, halo_d, std::make_tuple(fields...), ints);
             }
@@ -457,9 +457,9 @@ namespace gridtools {
                         if (ii != 0 || jj != 0 || kk != 0) {
                             using translate_P = translate_t<3, proc_layout>;
                             using map_type = typename translate_P::map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
 
                             if (base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1) {
                                 base_type::m_haloexch.set_send_to_size(
@@ -489,7 +489,7 @@ namespace gridtools {
 
         template <typename... Pointers>
         void unpack(Pointers *... fields) {
-            auto ints = meta::make_integer_sequence<unsigned int, sizeof...(Pointers)>{};
+            auto ints = std::make_integer_sequence<unsigned int, sizeof...(Pointers)>{};
             typedef translate_t<3, default_layout_map<3>::type> translate;
             if (recv_size[translate()(0, 0, -1)]) {
                 m_unpackZL_variadic(
@@ -549,9 +549,9 @@ namespace gridtools {
                         if (ii != 0 || jj != 0 || kk != 0) {
                             using translate_P = translate_t<3, proc_layout>;
                             using map_type = typename translate_P::map_type;
-                            const int ii_P = pack_get_elem<map_type::template at<0>()>::apply(ii, jj, kk);
-                            const int jj_P = pack_get_elem<map_type::template at<1>()>::apply(ii, jj, kk);
-                            const int kk_P = pack_get_elem<map_type::template at<2>()>::apply(ii, jj, kk);
+                            const int ii_P = make_array(ii, jj, kk)[map_type::template at<0>()];
+                            const int jj_P = make_array(ii, jj, kk)[map_type::template at<1>()];
+                            const int kk_P = make_array(ii, jj, kk)[map_type::template at<2>()];
 
                             if (base_type::pattern().proc_grid().proc(ii_P, jj_P, kk_P) != -1) {
                                 base_type::m_haloexch.set_send_to_size(
