@@ -13,6 +13,7 @@
 #include <iostream>
 #endif
 
+#include "../../common/defs.hpp"
 #include "../../common/gt_assert.hpp"
 #include "../GCL.hpp"
 #include "has_communicator.hpp"
@@ -464,12 +465,12 @@ namespace gridtools {
         */
         template <int I, int J, int K>
         void register_send_to_buffer(void *p, int s) {
-            BOOST_MPL_ASSERT_RELATION(I, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(I, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(J, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(J, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(K, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(K, <=, 1);
+            GT_STATIC_ASSERT(I >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(I <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K <= 1, GT_INTERNAL_ERROR);
 
             register_send_to_buffer(p, s, I, J, K);
         }
@@ -528,12 +529,12 @@ namespace gridtools {
         */
         template <int I, int J, int K>
         void register_receive_from_buffer(void *p, int s) {
-            BOOST_MPL_ASSERT_RELATION(I, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(I, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(J, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(J, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(K, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(K, <=, 1);
+            GT_STATIC_ASSERT(I >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(I <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K <= 1, GT_INTERNAL_ERROR);
 
             register_receive_from_buffer(p, s, I, J, K);
         }
@@ -580,12 +581,12 @@ namespace gridtools {
         */
         template <int I, int J, int K>
         void set_send_to_size(int s) {
-            BOOST_MPL_ASSERT_RELATION(I, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(I, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(J, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(J, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(K, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(K, <=, 1);
+            GT_STATIC_ASSERT(I >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(I <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K <= 1, GT_INTERNAL_ERROR);
 
             set_send_to_size(s, I, J, K);
         }
@@ -630,12 +631,12 @@ namespace gridtools {
         */
         template <int I, int J, int K>
         void set_receive_from_size(int s) {
-            BOOST_MPL_ASSERT_RELATION(I, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(I, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(J, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(J, <=, 1);
-            BOOST_MPL_ASSERT_RELATION(K, >=, -1);
-            BOOST_MPL_ASSERT_RELATION(K, <=, 1);
+            GT_STATIC_ASSERT(I >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(I <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(J <= 1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K >= -1, GT_INTERNAL_ERROR);
+            GT_STATIC_ASSERT(K <= 1, GT_INTERNAL_ERROR);
 
             set_receive_from_size(s, I, J, K);
         }
