@@ -12,22 +12,19 @@
 
 #include <cstddef>
 
-#include "defs.hpp"
 #include "drop_front.hpp"
 #include "macros.hpp"
 #include "reverse.hpp"
 
 namespace gridtools {
     namespace meta {
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <std::size_t N, class List>
-            GT_META_DEFINE_ALIAS(drop_back_c, reverse, (typename drop_front_c<N, typename reverse<List>::type>::type));
+            using drop_back_c = reverse<typename drop_front_c<N, typename reverse<List>::type>::type>;
 
             template <class N, class List>
-            GT_META_DEFINE_ALIAS(
-                drop_back, reverse, (typename drop_front_c<N::value, typename reverse<List>::type>::type));
-        }
-#if !GT_BROKEN_TEMPLATE_ALIASES
+            using drop_back = reverse<typename drop_front_c<N::value, typename reverse<List>::type>::type>;
+        } // namespace lazy
         template <std::size_t N, class List>
         using drop_back_c =
             typename lazy::reverse<typename lazy::drop_front_c<N, typename lazy::reverse<List>::type>::type>::type;
@@ -35,6 +32,5 @@ namespace gridtools {
         template <class N, class List>
         using drop_back = typename lazy::reverse<
             typename lazy::drop_front_c<N::value, typename lazy::reverse<List>::type>::type>::type;
-#endif
     } // namespace meta
 } // namespace gridtools
