@@ -11,19 +11,16 @@
 #pragma once
 
 #include "at.hpp"
-#include "defs.hpp"
 #include "length.hpp"
 #include "macros.hpp"
 
 namespace gridtools {
     namespace meta {
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <class List>
-            GT_META_DEFINE_ALIAS(last, at_c, (List, length<List>::value - 1));
+            using last = at_c<List, length<List>::value - 1>;
         }
-#if !GT_BROKEN_TEMPLATE_ALIASES
         template <class List>
         using last = typename lazy::at_c<List, length<List>::value - 1>::type;
-#endif
     } // namespace meta
 } // namespace gridtools
