@@ -20,20 +20,20 @@ namespace gridtools {
          *
          *   Alternative interpretation: apply function F to the arguments taken form List.
          */
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <template <class...> class, class...>
             struct rename;
         }
         GT_META_DELEGATE_TO_LAZY(rename, (template <class...> class F, class... Args), (F, Args...));
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <template <class...> class To, template <class...> class From, class... Ts>
             struct rename<To, From<Ts...>> {
-                using type = GT_META_CALL(To, Ts...);
+                using type = To<Ts...>;
             };
             template <template <class...> class To>
             struct rename<To> {
                 using type = curry_fun<meta::rename, To>;
             };
-        }
-    } // namespace meta
+        } // namespace lazy
+    }     // namespace meta
 } // namespace gridtools
