@@ -24,12 +24,15 @@ namespace gridtools {
         template <int I>
         struct pow_f {
             template <class Arg>
-            GT_FUNCTION GT_CONSTEXPR auto operator()(Arg const &arg) const
-                GT_AUTO_RETURN(gt_pow<I>::template apply(arg));
+            GT_FUNCTION GT_CONSTEXPR auto operator()(Arg const &arg) const {
+                return gt_pow<I>::template apply(arg);
+            }
         };
 
         template <int I, class Arg>
-        GT_FUNCTION GT_CONSTEXPR auto pow(Arg arg) GT_AUTO_RETURN(make_expr(pow_f<I>{}, arg));
+        GT_FUNCTION GT_CONSTEXPR auto pow(Arg arg) -> decltype(make_expr(pow_f<I>(), Arg())) {
+            return make_expr(pow_f<I>(), arg);
+        }
         /** @} */
         /** @} */
     } // namespace expressions
