@@ -24,11 +24,15 @@ namespace gridtools {
 
         struct times_f {
             template <class Lhs, class Rhs>
-            GT_FUNCTION GT_CONSTEXPR auto operator()(Lhs const &lhs, Rhs const &rhs) const GT_AUTO_RETURN(lhs *rhs);
+            GT_FUNCTION GT_CONSTEXPR auto operator()(Lhs const &lhs, Rhs const &rhs) const {
+                return lhs * rhs;
+            }
         };
 
         template <class Lhs, class Rhs>
-        GT_FUNCTION GT_CONSTEXPR auto operator*(Lhs lhs, Rhs rhs)GT_AUTO_RETURN(make_expr(times_f{}, lhs, rhs));
+        GT_FUNCTION GT_CONSTEXPR auto operator*(Lhs lhs, Rhs rhs) -> decltype(make_expr(times_f(), lhs, rhs)) {
+            return make_expr(times_f(), lhs, rhs);
+        }
         /** @} */
         /** @} */
     } // namespace expressions
