@@ -12,28 +12,25 @@
 #include <type_traits>
 
 #include "../common/defs.hpp"
+#include "../common/integral_constant.hpp"
 
 namespace gridtools {
-    template <int_t I, uint_t NColors>
+    template <int_t I, int_t NColors>
     struct location_type {
         static const int_t value = I;
-        typedef static_uint<NColors> n_colors; //! <- is the number of locations of this type
+        typedef integral_constant<int_t, NColors> n_colors; //! <- is the number of locations of this type
     };
 
     template <typename T>
     struct is_location_type : std::false_type {};
 
-    template <int I, uint_t NColors>
+    template <int I, int_t NColors>
     struct is_location_type<location_type<I, NColors>> : std::true_type {};
 
     namespace enumtype {
-        typedef static_int<0> cells_index;
-        typedef static_int<1> edges_index;
-        typedef static_int<2> vertices_index;
-
-        typedef location_type<cells_index::value, 2> cells;
-        typedef location_type<edges_index::value, 3> edges;
-        typedef location_type<vertices_index::value, 1> vertices;
+        typedef location_type<0, 2> cells;
+        typedef location_type<1, 3> edges;
+        typedef location_type<2, 1> vertices;
 
         // a null or default location type indicate the absence of location type, therefore coloring is not applied,
         // and therefore the number of colors should be 1 (used in other parts of the code)
