@@ -23,7 +23,7 @@
 */
 namespace gridtools {
     /** @brief Descriptors for  Multi Stage Stencil (MSS) */
-    template <typename ExecutionEngine, typename EsfDescrSequence, typename CacheSequence = std::tuple<>>
+    template <typename ExecutionEngine, typename EsfDescrSequence, typename CacheSequence>
     struct mss_descriptor {
         GT_STATIC_ASSERT((meta::all_of<is_esf_descriptor, EsfDescrSequence>::value), GT_INTERNAL_ERROR);
         GT_STATIC_ASSERT((meta::all_of<is_cache, CacheSequence>::value), GT_INTERNAL_ERROR);
@@ -35,5 +35,5 @@ namespace gridtools {
     };
 
     template <typename Mss>
-    GT_META_DEFINE_ALIAS(is_mss_descriptor, meta::is_instantiation_of, (mss_descriptor, Mss));
+    using is_mss_descriptor = meta::is_instantiation_of<mss_descriptor, Mss>;
 } // namespace gridtools
