@@ -17,7 +17,6 @@
 #include "../../common/integral_constant.hpp"
 #include "../../common/tuple.hpp"
 #include "../../common/tuple_util.hpp"
-#include "../../meta/defs.hpp"
 #include "../../meta/id.hpp"
 #include "../../meta/logical.hpp"
 #include "../../meta/macros.hpp"
@@ -125,6 +124,8 @@
  *
  *  - Stride sid::get_stride<I>(Strides)
  *
+ * TODO(anstaf): Document lower/upper bounds stuff when the API will be finally settled.
+ *
  */
 
 namespace gridtools {
@@ -143,8 +144,9 @@ namespace gridtools {
             struct get_static_const_value;
             template <class T>
             struct get_static_const_value<T,
-                enable_if_t<std::is_integral<decltype(T::value)>::value && std::is_const<decltype(T::value)>::value &&
-                            !std::is_member_pointer<decltype(&T::value)>::value>>
+                std::enable_if_t<std::is_integral<decltype(T::value)>::value &&
+                                 std::is_const<decltype(T::value)>::value &&
+                                 !std::is_member_pointer<decltype(&T::value)>::value>>
                 : std::integral_constant<decltype(T::value), T::value> {};
 
             /**
@@ -156,9 +158,9 @@ namespace gridtools {
             struct is_integral_constant : std::false_type {};
             template <class T>
             struct is_integral_constant<T,
-                enable_if_t<std::is_empty<T>::value && std::is_integral<decltype(T::value)>::value &&
-                            std::is_convertible<T, typename get_static_const_value<T>::value_type>::value &&
-                            T() == get_static_const_value<T>::value>> : std::true_type {};
+                std::enable_if_t<std::is_empty<T>::value && std::is_integral<decltype(T::value)>::value &&
+                                 std::is_convertible<T, typename get_static_const_value<T>::value_type>::value &&
+                                 T() == get_static_const_value<T>::value>> : std::true_type {};
 
             /**
              *  generic trait for integral constant of Val
@@ -169,38 +171,35 @@ namespace gridtools {
             struct is_integral_constant_of : std::false_type {};
 
             template <class T, int Val>
-            struct is_integral_constant_of<T, Val, enable_if_t<is_integral_constant<T>::value && T() == Val>>
+            struct is_integral_constant_of<T, Val, std::enable_if_t<is_integral_constant<T>::value && T() == Val>>
                 : std::true_type {};
 
             /////// BEGIN defaults PART /////
-            template <class...>
-            struct default_strides_templ;
-            template <>
-            struct default_strides_templ<> {};
-            using default_strides = default_strides_templ<>;
 
             template <class Ptr>
             auto sid_get_default_ptr_diff(Ptr const &ptr) -> decltype(ptr - ptr);
 
             template <class Ptr>
             using default_ptr_diff = decltype(::gridtools::sid::concept_impl_::sid_get_default_ptr_diff(
-                std::declval<add_lvalue_reference_t<add_const_t<Ptr>>>()));
+                std::declval<std::add_lvalue_reference_t<std::add_const_t<Ptr>>>()));
 
             template <class T, class = void>
             struct is_empty_or_tuple_of_empties : std::is_empty<T> {};
 
-            template <class Tup, class Types = GT_META_CALL(tuple_util::traits::to_types, Tup)>
-            GT_META_DEFINE_ALIAS(is_tuple_of_empties, meta::all_of, (is_empty_or_tuple_of_empties, Types));
+            template <class Tup, class Types = tuple_util::traits::to_types<Tup>>
+            using is_tuple_of_empties = meta::all_of<is_empty_or_tuple_of_empties, Types>;
 
             template <class Tup>
-            struct is_empty_or_tuple_of_empties<Tup, enable_if_t<is_tuple_of_empties<Tup>::value>> : std::true_type {};
+            struct is_empty_or_tuple_of_empties<Tup, std::enable_if_t<is_tuple_of_empties<Tup>::value>>
+                : std::true_type {};
 
-            GT_META_LAZY_NAMESPACE {
+            namespace lazy {
                 template <class, class = void>
                 struct default_kind;
                 template <class T>
-                struct default_kind<T, enable_if_t<is_empty_or_tuple_of_empties<decay_t<T>>::value>> : std::decay<T> {};
-            }
+                struct default_kind<T, std::enable_if_t<is_empty_or_tuple_of_empties<std::decay_t<T>>::value>>
+                    : std::decay<T> {};
+            } // namespace lazy
             GT_META_DELEGATE_TO_LAZY(default_kind, class T, T);
             /////// END defaults PART ///////
 
@@ -211,6 +210,8 @@ namespace gridtools {
             not_provided sid_get_strides(...);
             not_provided sid_get_ptr_diff(...);
             not_provided sid_get_strides_kind(...);
+            not_provided sid_get_lower_bounds(...);
+            not_provided sid_get_upper_bounds(...);
 
             // BEGIN `get_origin` PART
 
@@ -218,14 +219,15 @@ namespace gridtools {
              *  `get_origin` delegates to `sid_get_origin`
              */
             template <class Sid>
-            GT_CONSTEXPR auto get_origin(Sid &obj) GT_AUTO_RETURN(sid_get_origin(obj));
+            auto get_origin(Sid &obj) -> decltype(sid_get_origin(obj)) {
+                return sid_get_origin(obj);
+            }
 
             /**
              *  C-array specialization
              */
-            template <class T, class Res = gridtools::add_pointer_t<gridtools::remove_all_extents_t<T>>>
-            GT_CONSTEXPR gridtools::enable_if_t<std::is_array<T>::value, host_device::simple_ptr_holder<Res>>
-            get_origin(T &obj) {
+            template <class T, class Res = std::add_pointer_t<std::remove_all_extents_t<T>>>
+            std::enable_if_t<std::is_array<T>::value, host_device::simple_ptr_holder<Res>> get_origin(T &obj) {
                 return {(Res)obj};
             }
 
@@ -239,7 +241,7 @@ namespace gridtools {
              *  `Ptr` type is deduced from `get_origin`
              */
             template <class Sid, class PtrHolder = ptr_holder_type<Sid>>
-            using ptr_type = decay_t<decltype(std::declval<PtrHolder>()())>;
+            using ptr_type = std::decay_t<decltype(std::declval<PtrHolder>()())>;
 
             /**
              *  `Reference` type is deduced from `Ptr` type
@@ -255,10 +257,10 @@ namespace gridtools {
              *  a proxy for sid_get_ptr_diff ADL resolution
              */
             template <class Sid, class Res = decltype(sid_get_ptr_diff(std::declval<Sid const &>()))>
-            enable_if_t<!std::is_same<Res, not_provided>::value, Res> get_ptr_diff(Sid const &);
+            std::enable_if_t<!std::is_same<Res, not_provided>::value, Res> get_ptr_diff(Sid const &);
 
             template <class Sid, class Res = decltype(sid_get_ptr_diff(std::declval<Sid const &>()))>
-            enable_if_t<std::is_same<Res, not_provided>::value, default_ptr_diff<ptr_type<Sid>>> get_ptr_diff(
+            std::enable_if_t<std::is_same<Res, not_provided>::value, default_ptr_diff<ptr_type<Sid>>> get_ptr_diff(
                 Sid const &);
 
             /**
@@ -275,35 +277,33 @@ namespace gridtools {
              *  `get_strides` delegates to `sid_get_strides`
              */
             template <class Sid, class Res = decltype(sid_get_strides(std::declval<Sid const &>()))>
-            GT_CONSTEXPR enable_if_t<!std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, Res>
-            get_strides(Sid const &obj) {
+            std::enable_if_t<!std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, Res> get_strides(
+                Sid const &obj) {
                 return sid_get_strides(obj);
             }
 
             template <class Sid, class Res = decltype(sid_get_strides(std::declval<Sid const &>()))>
-            GT_CONSTEXPR
-                enable_if_t<std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, default_strides>
-                get_strides(Sid const &) {
+            std::enable_if_t<std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, tuple<>> get_strides(
+                Sid const &) {
                 return {};
             }
 
-            template <class T, size_t ElemSize = sizeof(remove_all_extents_t<T>)>
+            template <class T, size_t ElemSize = sizeof(std::remove_all_extents_t<T>)>
             struct get_array_strides {
                 using type = tuple<>;
             };
 
             template <class Inner, size_t ElemSize>
             struct get_array_strides<Inner[], ElemSize> {
-                using type = GT_META_CALL(meta::push_front,
-                    (typename get_array_strides<Inner, ElemSize>::type,
-                        integral_constant<ptrdiff_t, sizeof(Inner) / ElemSize>));
+                using type = meta::push_front<typename get_array_strides<Inner, ElemSize>::type,
+                    integral_constant<ptrdiff_t, sizeof(Inner) / ElemSize>>;
             };
 
             template <class Inner, size_t N, size_t ElemSize>
             struct get_array_strides<Inner[N], ElemSize> : get_array_strides<Inner[], ElemSize> {};
 
             template <class T>
-            constexpr enable_if_t<std::is_array<T>::value, typename get_array_strides<T>::type> get_strides(T const &) {
+            std::enable_if_t<std::is_array<T>::value, typename get_array_strides<T>::type> get_strides(T const &) {
                 return {};
             }
 
@@ -318,11 +318,11 @@ namespace gridtools {
             // BEGIN `strides_kind` PART
 
             template <class Sid, class Res = decltype(sid_get_strides_kind(std::declval<Sid const &>()))>
-            enable_if_t<!std::is_same<Res, not_provided>::value, Res> get_strides_kind(Sid const &);
+            std::enable_if_t<!std::is_same<Res, not_provided>::value, Res> get_strides_kind(Sid const &);
 
             template <class Sid, class Res = decltype(sid_get_strides_kind(std::declval<Sid const &>()))>
-            enable_if_t<std::is_same<Res, not_provided>::value, GT_META_CALL(default_kind, strides_type<Sid>)>
-            get_strides_kind(Sid const &);
+            std::enable_if_t<std::is_same<Res, not_provided>::value, default_kind<strides_type<Sid>>> get_strides_kind(
+                Sid const &);
 
             /**
              *  `strides_kind` is deduced from `get_strides_kind`
@@ -333,6 +333,61 @@ namespace gridtools {
 
             // END `strides_kind` PART
 
+            // BEGIN `get_lower_bounds`/`get_upper_bounds`
+
+            template <class Sid, class Res = decltype(sid_get_lower_bounds(std::declval<Sid const &>()))>
+            std::enable_if_t<!std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, Res>
+            get_lower_bounds(Sid const &obj) {
+                return sid_get_lower_bounds(obj);
+            }
+
+            template <class Sid, class Res = decltype(sid_get_upper_bounds(std::declval<Sid const &>()))>
+            std::enable_if_t<!std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, Res>
+            get_upper_bounds(Sid const &obj) {
+                return sid_get_upper_bounds(obj);
+            }
+
+            template <class Sid, class Res = decltype(sid_get_lower_bounds(std::declval<Sid const &>()))>
+            std::enable_if_t<std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, tuple<>>
+            get_lower_bounds(Sid const &) {
+                return {};
+            }
+
+            template <class Sid, class Res = decltype(sid_get_upper_bounds(std::declval<Sid const &>()))>
+            std::enable_if_t<std::is_same<Res, not_provided>::value && !std::is_array<Sid>::value, tuple<>>
+            get_upper_bounds(Sid const &) {
+                return {};
+            }
+
+            template <class T,
+                class Res = meta::rename<tuple, meta::repeat<std::rank<T>, integral_constant<ptrdiff_t, 0>>>>
+            std::enable_if_t<std::is_array<T>::value, Res> get_lower_bounds(T const &) {
+                return {};
+            }
+
+            template <class T>
+            struct array_extent_f {
+                template <class Dim>
+                using apply = integral_constant<ptrdiff_t, std::extent<T, Dim::value>::value>;
+            };
+
+            template <class T,
+                class Dims = meta::make_indices<std::rank<T>, tuple>,
+                class Res = meta::transform<array_extent_f<T>::template apply, Dims>>
+            std::enable_if_t<std::is_array<T>::value, Res> get_upper_bounds(T const &) {
+                return {};
+            }
+
+            template <class Sid>
+            using lower_bounds_type =
+                decltype(::gridtools::sid::concept_impl_::get_lower_bounds(std::declval<Sid const &>()));
+
+            template <class Sid>
+            using upper_bounds_type =
+                decltype(::gridtools::sid::concept_impl_::get_upper_bounds(std::declval<Sid const &>()));
+
+            // END `get_lower_bound`/`get_upper_bound`
+
             // BEGIN `shift` PART
 
             // no fallback for `sid_shift`
@@ -343,10 +398,8 @@ namespace gridtools {
              *  If stride of offset are zero or the target has no state, we don't need to shift
              */
             template <class T, class Stride, class Offset>
-            GT_META_DEFINE_ALIAS(need_shift,
-                bool_constant,
-                (!(std::is_empty<T>::value || is_integral_constant_of<Stride, 0>::value ||
-                    is_integral_constant_of<Offset, 0>::value)));
+            using need_shift = bool_constant<!(std::is_empty<T>::value || is_integral_constant_of<Stride, 0>::value ||
+                                               is_integral_constant_of<Offset, 0>::value)>;
 
             /**
              *  additional proxy is used here to ensure that evaluation context of `obj += stride * offset`
@@ -408,7 +461,8 @@ namespace gridtools {
              *  noop `shift` overload
              */
             template <class T, class Stride, class Offset>
-            GT_FUNCTION enable_if_t<!need_shift<T, Stride, Offset>::value> shift(T &, Stride const &, Offset const &) {}
+            GT_FUNCTION std::enable_if_t<!need_shift<T, Stride, Offset>::value> shift(
+                T &, Stride const &, Offset const &) {}
 
             /**
              * `shift` overload that delegates to `sid_shift`
@@ -418,9 +472,12 @@ namespace gridtools {
             template <class T,
                 class Stride,
                 class Offset,
-                enable_if_t<need_shift<T, Stride, Offset>::value && !is_default_shiftable<T, Stride>::value, int> = 0>
-            GT_FUNCTION auto shift(T &obj, Stride const &GT_RESTRICT stride, Offset const &GT_RESTRICT offset)
-                GT_AUTO_RETURN(sid_shift(obj, stride, offset));
+                std::enable_if_t<need_shift<T, std::decay_t<Stride>, Offset>::value &&
+                                     !is_default_shiftable<T, std::decay_t<Stride>>::value,
+                    int> = 0>
+            GT_FUNCTION decltype(auto) shift(T &obj, Stride &&stride, Offset offset) {
+                return sid_shift(obj, wstd::forward<Stride>(stride), offset);
+            }
 
             /**
              *  `shift` overload where both `stride` and `offset` are known in compile time
@@ -429,9 +486,10 @@ namespace gridtools {
                 class Stride,
                 class Offset,
                 int_t PtrOffset = get_static_const_value<Stride>::value *Offset::value>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    !(has_inc<T>::value && PtrOffset == 1) && !(has_dec<T>::value && PtrOffset == -1)>
-            shift(T &obj, Stride const &, Offset const &) {
+            GT_FUNCTION
+                std::enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
+                                 !(has_inc<T>::value && PtrOffset == 1) && !(has_dec<T>::value && PtrOffset == -1)>
+                shift(T &obj, Stride, Offset) {
                 obj += integral_constant<int_t, PtrOffset>{};
             }
 
@@ -442,9 +500,9 @@ namespace gridtools {
                 class Stride,
                 class Offset,
                 int_t PtrOffset = get_static_const_value<Stride>::value *Offset::value>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    has_inc<T>::value && PtrOffset == 1>
-            shift(T &obj, Stride const &, Offset const &) {
+            GT_FUNCTION std::enable_if_t<need_shift<T, Stride, Offset>::value &&
+                                         is_default_shiftable<T, Stride>::value && has_inc<T>::value && PtrOffset == 1>
+            shift(T &obj, Stride, Offset) {
                 ++obj;
             }
 
@@ -455,9 +513,9 @@ namespace gridtools {
                 class Stride,
                 class Offset,
                 int_t PtrOffset = get_static_const_value<Stride>::value *Offset::value>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    has_dec<T>::value && PtrOffset == -1>
-            shift(T &obj, Stride const &, Offset const &) {
+            GT_FUNCTION std::enable_if_t<need_shift<T, Stride, Offset>::value &&
+                                         is_default_shiftable<T, Stride>::value && has_dec<T>::value && PtrOffset == -1>
+            shift(T &obj, Stride, Offset) {
                 --obj;
             }
 
@@ -465,9 +523,10 @@ namespace gridtools {
              *  `shift` overload where the offset is 1
              */
             template <class T, class Stride, class Offset>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    !is_integral_constant<Stride>::value && is_integral_constant_of<Offset, 1>::value>
-            shift(T &obj, Stride const &GT_RESTRICT stride, Offset const &) {
+            GT_FUNCTION
+                std::enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
+                                 !is_integral_constant<Stride>::value && is_integral_constant_of<Offset, 1>::value>
+                shift(T &obj, Stride const &stride, Offset) {
                 obj += stride;
             }
 
@@ -475,10 +534,11 @@ namespace gridtools {
              *  `shift` overload where the offset is -1
              */
             template <class T, class Stride, class Offset>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    !is_integral_constant<Stride>::value &&
-                                    is_integral_constant_of<Offset, -1>::value && has_dec_assignment<T, Stride>::value>
-            shift(T &obj, Stride const &GT_RESTRICT stride, Offset const &) {
+            GT_FUNCTION
+                std::enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
+                                 !is_integral_constant<Stride>::value && is_integral_constant_of<Offset, -1>::value &&
+                                 has_dec_assignment<T, Stride>::value>
+                shift(T &obj, Stride const &stride, Offset) {
                 obj -= stride;
             }
 
@@ -486,9 +546,10 @@ namespace gridtools {
              *  `shift` overload where the stride is 1
              */
             template <class T, class Stride, class Offset>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    is_integral_constant_of<Stride, 1>::value && !is_integral_constant<Offset>::value>
-            shift(T &obj, Stride const &, Offset const &GT_RESTRICT offset) {
+            GT_FUNCTION
+                std::enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
+                                 is_integral_constant_of<Stride, 1>::value && !is_integral_constant<Offset>::value>
+                shift(T &obj, Stride, Offset offset) {
                 obj += offset;
             }
 
@@ -496,25 +557,26 @@ namespace gridtools {
              *  `shift` overload where the stride is -1
              */
             template <class T, class Stride, class Offset>
-            GT_FUNCTION enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                                    is_integral_constant_of<Stride, -1>::value &&
-                                    !is_integral_constant<Offset>::value && has_dec_assignment<T, Stride>::value>
-            shift(T &obj, Stride const &, Offset const &GT_RESTRICT offset) {
+            GT_FUNCTION
+                std::enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
+                                 is_integral_constant_of<Stride, -1>::value && !is_integral_constant<Offset>::value &&
+                                 has_dec_assignment<T, Stride>::value>
+                shift(T &obj, Stride, Offset offset) {
                 obj -= offset;
             }
 
             /**
              *  `shift` overload, default version
              */
-            template <class T, class Stride, class Offset>
-            GT_FUNCTION
-                enable_if_t<need_shift<T, Stride, Offset>::value && is_default_shiftable<T, Stride>::value &&
-                            !(is_integral_constant<Stride>::value && is_integral_constant<Offset>::value) &&
-                            !(is_integral_constant_of<Stride, 1>::value || is_integral_constant_of<Offset, 1>::value) &&
-                            !(has_dec_assignment<T, Stride>::value && (is_integral_constant_of<Stride, -1>::value ||
-                                                                          is_integral_constant_of<Offset, -1>::value))>
-                shift(T &obj, Stride const &GT_RESTRICT stride, Offset const &GT_RESTRICT offset) {
-                obj += stride * offset;
+            template <class T, class Stride, class Offset, class Decayed = std::decay_t<Stride>>
+            GT_FUNCTION std::enable_if_t<
+                need_shift<T, Decayed, Offset>::value && is_default_shiftable<T, Decayed>::value &&
+                !(is_integral_constant<Decayed>::value && is_integral_constant<Offset>::value) &&
+                !(is_integral_constant_of<Decayed, 1>::value || is_integral_constant_of<Offset, 1>::value) &&
+                !(has_dec_assignment<T, Decayed>::value &&
+                    (is_integral_constant_of<Decayed, -1>::value || is_integral_constant_of<Offset, -1>::value))>
+            shift(T &obj, Stride &&stride, Offset offset) {
+                obj += wstd::forward<Stride>(stride) * offset;
             }
 
             // END `shift` PART
@@ -536,7 +598,13 @@ namespace gridtools {
              *  Meta predicate that validates a list of stride type against `shift` function
              */
             template <class StrideTypes, class T>
-            GT_META_DEFINE_ALIAS(are_valid_strides, meta::all_of, (is_valid_stride<T>::template apply, StrideTypes));
+            using are_valid_strides = meta::all_of<is_valid_stride<T>::template apply, StrideTypes>;
+
+            template <class Bound>
+            using is_valid_bound = std::is_convertible<Bound, int_t>;
+
+            template <class BoundTypes>
+            using are_valid_bounds = meta::all_of<is_valid_bound, BoundTypes>;
 
             /**
              *  Sfinae unsafe version of `is_sid` predicate
@@ -548,63 +616,60 @@ namespace gridtools {
                 class ReferenceType = reference_type<Sid>,
                 class PtrDiff = ptr_diff_type<Sid>,
                 class StridesType = strides_type<Sid>,
-                class StrideTypeList = GT_META_CALL(tuple_util::traits::to_types, decay_t<StridesType>),
-                class StridesKind = strides_kind<Sid>>
-            GT_META_DEFINE_ALIAS(is_sid,
-                conjunction,
-                (
-                    // `is_trivially_copyable` check is applied to the types that are will be passed from host to device
-                    std::is_trivially_copyable<PtrHolder>,
-                    std::is_trivially_copyable<StridesType>,
+                class StrideTypeList = tuple_util::traits::to_types<std::decay_t<StridesType>>,
+                class StridesKind = strides_kind<Sid>,
+                class LowerBoundsType = lower_bounds_type<Sid>,
+                class UpperBoundsType = upper_bounds_type<Sid>>
+            using is_sid = conjunction<
 
-                    // verify that `PtrDiff` is sane
-                    std::is_default_constructible<PtrDiff>,
-                    std::is_convertible<decltype(std::declval<Ptr const &>() + std::declval<PtrDiff const &>()), Ptr>,
+                // `is_trivially_copyable` check is applied to the types that are will be passed from host to device
+                std::is_trivially_copyable<PtrHolder>,
+                std::is_trivially_copyable<StridesType>,
 
-                    // `PtrHolder` supports `+` as well
-                    // TODO(anstaf): we can do better here: verify that if we transform PtrHolder that way the result
-                    //               thing also models SID
-                    std::is_same<decay_t<decltype(std::declval<PtrHolder const &>() + std::declval<PtrDiff const &>())>,
-                        PtrHolder>,
+                // verify that `PtrDiff` is sane
+                std::is_default_constructible<PtrDiff>,
+                std::is_convertible<decltype(std::declval<Ptr const &>() + std::declval<PtrDiff const &>()), Ptr>,
 
-                    // verify that `Reference` is sane
-                    negation<std::is_void<ReferenceType>>,
+                // `PtrHolder` supports `+` as well
+                // TODO(anstaf): we can do better here: verify that if we transform PtrHolder that way the result
+                //               thing also models SID
+                std::is_same<
+                    std::decay_t<decltype(std::declval<PtrHolder const &>() + std::declval<PtrDiff const &>())>,
+                    PtrHolder>,
 
-                    // all strides must be applied via `shift` with both `Ptr` and `PtrDiff`
-                    are_valid_strides<StrideTypeList, Ptr>,
-                    are_valid_strides<StrideTypeList, PtrDiff>));
+                // verify that `Reference` is sane
+                negation<std::is_void<ReferenceType>>,
+
+                // all strides must be applied via `shift` with both `Ptr` and `PtrDiff`
+                are_valid_strides<StrideTypeList, Ptr>,
+                are_valid_strides<StrideTypeList, PtrDiff>,
+
+                are_valid_bounds<tuple_util::traits::to_types<std::decay_t<LowerBoundsType>>>,
+                are_valid_bounds<tuple_util::traits::to_types<std::decay_t<UpperBoundsType>>>>;
 
         } // namespace concept_impl_
 
         // Meta functions
 
-#if GT_BROKEN_TEMPLATE_ALIASES
-#define GT_SID_DELEGATE_FROM_IMPL(name) \
-    template <class Sid>                \
-    struct name : meta::id<concept_impl_::name<Sid>> {}
-#else
-#define GT_SID_DELEGATE_FROM_IMPL(name) using concept_impl_::name
-#endif
+        using concept_impl_::lower_bounds_type;
+        using concept_impl_::ptr_diff_type;
+        using concept_impl_::ptr_holder_type;
+        using concept_impl_::ptr_type;
+        using concept_impl_::reference_type;
+        using concept_impl_::strides_kind;
+        using concept_impl_::strides_type;
+        using concept_impl_::upper_bounds_type;
 
-        GT_SID_DELEGATE_FROM_IMPL(ptr_holder_type);
-        GT_SID_DELEGATE_FROM_IMPL(ptr_type);
-        GT_SID_DELEGATE_FROM_IMPL(ptr_diff_type);
-        GT_SID_DELEGATE_FROM_IMPL(reference_type);
-        GT_SID_DELEGATE_FROM_IMPL(strides_type);
-        GT_SID_DELEGATE_FROM_IMPL(strides_kind);
-
-        GT_SID_DELEGATE_FROM_IMPL(default_ptr_diff);
-
-#undef GT_SID_DELEGATE_FROM_IMPL
+        using concept_impl_::default_ptr_diff;
 
         // Runtime functions
+        using concept_impl_::get_lower_bounds;
         using concept_impl_::get_origin;
         using concept_impl_::get_strides;
+        using concept_impl_::get_upper_bounds;
         using concept_impl_::shift;
 
         // Default behaviour
-        using concept_impl_::default_kind;
-        using concept_impl_::default_strides;
         using default_stride = integral_constant<int_t, 0>;
 
         /**
@@ -613,27 +678,23 @@ namespace gridtools {
         template <class T, class = void>
         struct is_sid : std::false_type {};
         template <class T>
-        struct is_sid<T, enable_if_t<std::is_array<T>::value>> : std::true_type {};
-        template <class T>
-        struct is_sid<T, enable_if_t<concept_impl_::is_sid<T>::value>> : std::true_type {};
+        struct is_sid<T, std::enable_if_t<concept_impl_::is_sid<T>::value>> : std::true_type {};
 
         // Auxiliary API
 
         /**
          *  The type of the element of the SID
          */
-        template <class Sid, class Ref = GT_META_CALL(reference_type, Sid)>
-        GT_META_DEFINE_ALIAS(element_type, meta::id, decay_t<Ref>);
+        template <class Sid>
+        using element_type = std::remove_reference_t<reference_type<Sid>>;
 
         /**
          *  The const variation of the reference type
          */
-        template <class Sid, class Ref = GT_META_CALL(reference_type, Sid)>
-        GT_META_DEFINE_ALIAS(const_reference_type,
-            meta::id,
-            (conditional_t<std::is_reference<Ref>::value,
-                add_lvalue_reference_t<add_const_t<remove_reference_t<Ref>>>,
-                add_const_t<Ref>>));
+        template <class Sid, class Ref = reference_type<Sid>>
+        using const_reference_type = std::conditional_t<std::is_reference<Ref>::value,
+            std::add_lvalue_reference_t<std::add_const_t<std::remove_reference_t<Ref>>>,
+            std::add_const_t<Ref>>;
 
         /**
          *  A getter from Strides to the given stride.
@@ -641,18 +702,31 @@ namespace gridtools {
          *  If `Stride` doesn't have `Key`, integral_constant<int_t, 0> is returned.
          *  Which allows to silently ignore the offsets in non existing dimensions.
          */
-        template <class Key, class Strides, enable_if_t<has_key<decay_t<Strides>, Key>::value, int> = 0>
-        constexpr GT_FUNCTION auto get_stride(Strides &&strides)
-            GT_AUTO_RETURN(gridtools::host_device::at_key<Key>(strides));
-        template <class Key, class Strides, enable_if_t<!has_key<decay_t<Strides>, Key>::value, int> = 0>
-        constexpr GT_FUNCTION default_stride get_stride(Strides &&) {
-            return {};
+        template <class Key, class Strides>
+        GT_CONSTEXPR GT_FUNCTION decltype(auto) get_stride(Strides &&strides) {
+            return gridtools::host_device::at_key_with_default<Key, default_stride>(wstd::forward<Strides>(strides));
         }
 
-        struct get_origin_f {
-            template <class T>
-            constexpr auto operator()(T &obj) const GT_AUTO_RETURN(get_origin(obj));
-        };
+        /**
+         *  A variation of get_stride helper that works with the strides that are maps of of maps.
+         *  I.e. `composite`.
+         */
+        template <class Key,
+            class Dim,
+            class Strides,
+            std::enable_if_t<has_key<std::decay_t<Strides>, Dim>::value, int> = 0>
+        GT_CONSTEXPR GT_FUNCTION decltype(auto) get_stride_element(Strides &&strides) {
+            return gridtools::host_device::at_key<Key>(
+                gridtools::host_device::at_key<Dim>(wstd::forward<Strides>(strides)));
+        }
+
+        template <class Key,
+            class Dim,
+            class Strides,
+            std::enable_if_t<!has_key<std::decay_t<Strides>, Dim>::value, int> = 0>
+        GT_CONSTEXPR GT_FUNCTION integral_constant<int_t, 0> get_stride_element(Strides &&) {
+            return {};
+        }
     } // namespace sid
 
     /*
