@@ -17,5 +17,7 @@ namespace gridtools {
         using i = integral_constant<int, 0>;
         using j = integral_constant<int, 1>;
         using k = integral_constant<int, 2>;
+        struct c;
+        struct thread;
     } // namespace dim
 } // namespace gridtools
