@@ -2,17 +2,14 @@
 
 source $(dirname "$BASH_SOURCE")/base.sh
 
-module load PE/17.06
-module load python/3.6.2-gmvolf-17.02
-
 module load craype-network-infiniband
 module load craype-haswell
 module load craype-accel-nvidia35
 module load cray-libsci
-module swap cudatoolkit/8.0.61
+module load cudatoolkit/8.0.61
 module load mvapich2gdr_gnu/2.2_cuda_8.0
 module load gcc/5.4.0-2.26
-module load /users/jenkins/easybuild/kesch/modules/all/cmake/3.12.4
+module load /users/jenkins/easybuild/kesch/modules/all/cmake/3.14.5
 
 export BOOST_ROOT=/project/c14/install/kesch/boost/boost_1_67_0
 export CUDATOOLKIT_HOME=$CUDA_PATH
