@@ -11,7 +11,7 @@ grid=structured
 for real_type in float double; do
     for domain in 128 256; do
         for label in tave kesch daint-cn; do
-            for env in gcc clang icc nvcc_gcc nvcc_clang; do
+            for env in gcc clang icc nvcc_gcc nvcc_clang clang_nvcc; do
                 for backend in x86 mc cuda; do
                     current="$grid/$real_type/$domain/${label%-*}_$env/result.$backend.json"
                     src="http://jenkins-mch.cscs.ch/view/GridTools/job/GridTools_perftest_PR/$1/env=$env,label=$label,real_type=$real_type/artifact/build/pyutils/perftest/results/$current"
