@@ -8,7 +8,7 @@
 
 program main
     use iso_c_binding
-    use gt_handle
+    use bindgen_handle
     use implementation
     implicit none
     integer, parameter :: i = 9, j = 10, k = 11
@@ -28,9 +28,9 @@ program main
     if (any(in /= initial())) stop 1
     if (any(out /= initial())) stop 1
 
-    call gt_release(stencil)
-    call gt_release(out_handle)
-    call gt_release(in_handle)
+    call bindgen_release(stencil)
+    call bindgen_release(out_handle)
+    call bindgen_release(in_handle)
 
     print *, "It works!"
 
