@@ -16,20 +16,6 @@
 
 using namespace gridtools;
 
-TEST(layout_map_metafunctions, filter_layout) {
-
-    {
-        using layout_map_t = layout_map<0, 1, 2, 3>;
-        using filtered_layout_map_t = filter_layout<layout_map_t, selector<1, 1, 0, 1>>::type;
-        GT_STATIC_ASSERT((std::is_same<filtered_layout_map_t, layout_map<0, 1, -1, 2>>::value), "Error");
-    }
-    {
-        using layout_map_t = layout_map<3, 1, 2, 0>;
-        using filtered_layout_map_t = filter_layout<layout_map_t, selector<1, 0, 0, 1>>::type;
-        GT_STATIC_ASSERT((std::is_same<filtered_layout_map_t, layout_map<1, -1, -1, 0>>::value), "Error");
-    }
-}
-
 TEST(layout_map_metafunctions, extend_layout_map) {
     {
         using layout_map_t = layout_map<0, 1, 2, 3>;
