@@ -18,107 +18,6 @@
 
 using namespace gridtools;
 
-// static type tests for x86 and naive backend
-template <class Backend>
-struct static_type_tests {
-    using storage_traits_t = storage_traits<Backend>;
-
-    /*########## STORAGE INFO CHECKS ########## */
-    // storage info check
-    typedef typename storage_traits_t::template storage_info_t<0, 3, halo<1, 2, 3>> storage_info_ty;
-    GT_STATIC_ASSERT(
-        (is_storage_info<storage_info_ty>::type::value), "is_storage_info metafunction is not working anymore");
-    GT_STATIC_ASSERT(
-        (std::is_same<storage_info_ty, storage_info<0, layout_map<0, 1, 2>, halo<1, 2, 3>, alignment<1>>>::type::value),
-        "storage info test failed");
-
-    // special layout
-    typedef typename storage_traits_t::template special_storage_info_t<0, selector<1, 1, 0>, halo<1, 2, 3>>
-        special_storage_info_ty;
-    GT_STATIC_ASSERT((std::is_same<special_storage_info_ty,
-                         storage_info<0, layout_map<0, 1, -1>, halo<1, 2, 3>, alignment<1>>>::type::value),
-        "storage info test failed");
-
-    /*########## DATA STORE CHECKS ########## */
-    typedef typename storage_traits_t::template data_store_t<double, storage_info_ty> data_store_t;
-    GT_STATIC_ASSERT((std::is_same<typename data_store_t::storage_info_t, storage_info_ty>::type::value),
-        "data store info type is wrong");
-    GT_STATIC_ASSERT(
-        (std::is_same<typename data_store_t::data_t, double>::type::value), "data store value type is wrong");
-
-    // storage check
-    GT_STATIC_ASSERT((std::is_same<typename data_store_t::storage_t, host_storage<double>>::type::value),
-        "data store storage type is wrong");
-};
-
-#ifdef __CUDACC__
-// static type tests for Cuda backend
-template <>
-struct static_type_tests<backend::cuda> {
-    using storage_traits_t = storage_traits<backend::cuda>;
-
-    /*########## STORAGE INFO CHECKS ########## */
-    // storage info check
-    typedef storage_traits_t::storage_info_t<0, 3, halo<1, 2, 3>> storage_info_ty;
-    GT_STATIC_ASSERT(
-        (is_storage_info<storage_info_ty>::type::value), "is_storage_info metafunction is not working anymore");
-    GT_STATIC_ASSERT((std::is_same<storage_info_ty,
-                         storage_info<0, layout_map<2, 1, 0>, halo<1, 2, 3>, alignment<32>>>::type::value),
-        "storage info test failed");
-
-    // special layout
-    typedef storage_traits_t::special_storage_info_t<0, selector<1, 1, 0>, halo<1, 2, 3>> special_storage_info_ty;
-    GT_STATIC_ASSERT((std::is_same<special_storage_info_ty,
-                         storage_info<0, layout_map<1, 0, -1>, halo<1, 2, 3>, alignment<32>>>::type::value),
-        "storage info test failed");
-
-    /*########## DATA STORE CHECKS ########## */
-    typedef storage_traits_t::data_store_t<double, storage_info_ty> data_store_t;
-    GT_STATIC_ASSERT((std::is_same<typename data_store_t::storage_info_t, storage_info_ty>::type::value),
-        "data store info type is wrong");
-    GT_STATIC_ASSERT(
-        (std::is_same<typename data_store_t::data_t, double>::type::value), "data store value type is wrong");
-
-    // storage check
-    GT_STATIC_ASSERT((std::is_same<typename data_store_t::storage_t, cuda_storage<double>>::type::value),
-        "data store storage type is wrong");
-};
-#endif
-
-#ifndef GT_ICOSAHEDRAL_GRIDS
-// static type tests for Mic backend
-template <>
-struct static_type_tests<backend::mc> {
-    using storage_traits_t = storage_traits<backend::mc>;
-
-    /*########## STORAGE INFO CHECKS ########## */
-    // storage info check
-    typedef storage_traits_t::storage_info_t<0, 3, halo<1, 2, 3>> storage_info_ty;
-    GT_STATIC_ASSERT(
-        (is_storage_info<storage_info_ty>::type::value), "is_storage_info metafunction is not working anymore");
-    GT_STATIC_ASSERT(
-        (std::is_same<storage_info_ty, storage_info<0, layout_map<2, 0, 1>, halo<1, 2, 3>, alignment<8>>>::type::value),
-        "storage info test failed");
-
-    // special layout
-    typedef storage_traits_t::special_storage_info_t<0, selector<1, 1, 0>, halo<1, 2, 3>> special_storage_info_ty;
-    GT_STATIC_ASSERT((std::is_same<special_storage_info_ty,
-                         storage_info<0, layout_map<1, 0, -1>, halo<1, 2, 3>, alignment<8>>>::type::value),
-        "storage info test failed");
-
-    /*########## DATA STORE CHECKS ########## */
-    typedef storage_traits_t::data_store_t<double, storage_info_ty> data_store_t;
-    GT_STATIC_ASSERT((std::is_same<typename data_store_t::storage_info_t, storage_info_ty>::type::value),
-        "data store info type is wrong");
-    GT_STATIC_ASSERT(
-        (std::is_same<typename data_store_t::data_t, double>::type::value), "data store value type is wrong");
-
-    // storage check
-    GT_STATIC_ASSERT((std::is_same<typename data_store_t::storage_t, mc_storage<double>>::type::value),
-        "data store storage type is wrong");
-};
-#endif
-
 #ifdef __CUDACC__
 template <typename View>
 __global__ void kernel(View v) {
